@@ -1,4 +1,5 @@
 # main runner
+from datetime import datetime
 import pandas as pd
 from dateutil.relativedelta import relativedelta
 
@@ -25,6 +26,50 @@ def get_train_end_date(time_series_df, training_holdout):
     return train_end_date
 
 
+def get_forecast_periods(last_day, horizon_years, frequency) -> list:
+    # Get start and end dates
+    max_week = last_day.strftime("%Y %W")
+    last_week_start = datetime.strptime(f"{max_week} w1", "%Y %W w%w")
+    start_date = last_week_start + relativedelta(days=7)
+    end_date = start_date + relativedelta(years=horizon_years)
+    if frequency == "W-MON":
+        # Truncate if the last week is the same as the first
+        period_list = pd.date_range(start=start_date, end=end_date, freq=frequency)
+        first_week_number = pd.Timestamp(period_list[0]).isocalendar()[1]
+        final_week_number = pd.Timestamp(period_list[-1]).isocalendar()[1]
+        drop_final_week = False
+        if first_week_number not in [52, 53]:
+            if final_week_number == first_week_number:
+                drop_final_week = True
+        else:
+            # Handle forecasts that start on the last day of the year
+            first_year = pd.Timestamp(period_list[0]).isocalendar()[0]
+            first_year_weeks = datetime(first_year, 12, 28).isocalendar()[1]
+            final_year = pd.Timestamp(period_list[-1]).isocalendar()[0]
+            final_year_weeks = datetime(final_year, 12, 28).isocalendar()[1]
+            if first_week_number == 52:
+                if final_week_number == first_week_number:
+                    # Only drop if final year doesn't have 53 weeks
+                    if final_year_weeks != 53:
+                        drop_final_week = True
+                elif final_week_number == 53:
+                    # Drop if first year doesn't have 53 weeks
+                    if first_year_weeks != 53:
+                        drop_final_week = True
+            elif first_week_number == 53:
+                if final_week_number == first_week_number:
+                    # Always drop if weeks are the same
+                    period_list = period_list[:-1]
+                elif final_week_number == 52:
+                    # Drop if final year doesn't have 53 weeks
+                    if final_year_weeks != 53:
+                        drop_final_week = True
+        if drop_final_week:
+            period_list = period_list[:-1]
+
+    return period_list
+
+
 def run_forecast_ensemble(
         dataframe,
         date_column,
@@ -50,16 +95,17 @@ def run_forecast_ensemble(
     df = df[[DATE_COLUMN_NAME, VALUE_COLUMN_NAME]]
 
     # Create Future Forecast Periods
-    start_date = pd.to_datetime(dataframe[DATE_COLUMN_NAME]).max() + relativedelta(days=6)
-    end_date = start_date + relativedelta(years=forecast_horizon_years)
+    last_date = pd.to_datetime(dataframe[DATE_COLUMN_NAME]).max()
+    period_list = get_forecast_periods(last_date, forecast_horizon_years, frequency)
+
     # Add additional period if lag is requested
     if prediction_lag != 0:
         if frequency == "W-MON":
             delta = relativedelta(days=7)
         elif frequency == "MS":
             delta = relativedelta(months=1)
-        end_date = end_date + delta
-    period_list = pd.date_range(start=start_date, end=end_date, freq=frequency)
+        end_date = period_list[-1] + delta
+        period_list = period_list.append(pd.DatetimeIndex([end_date]))
 
     # Mark dataframe with training/testing split
     train_end_date = get_train_end_date(df, training_holdout_pct)
