@@ -159,7 +159,7 @@ class FBNeuralProphet(BaseModel):
         """
         df = dataframe.rename(columns={DATE_COLUMN_NAME: "ds", VALUE_COLUMN_NAME: "y"})
 
-        model = NeuralProphet(yearly_seasonality=30)
+        model = NeuralProphet(yearly_seasonality=35)
         model.fit(df=df, freq=frequency)
 
         future = model.make_future_dataframe(
@@ -446,14 +446,20 @@ class XGBoost(BaseModel):
             train = pd.concat([train, pd.DataFrame(row).T])
 
         # Add in trend and combine
-        backtest_output = pd.merge(left=test, right=decomposed_dataframe, how="left", right_index=True, left_index=True)
-        backtest_output["trend"] = utils.get_linear_predictions(
+        backtest_output = pd.merge(
+            left=test,
+            right=decomposed_dataframe,
+            how="left",
+            right_index=True,
+            left_index=True)
+        backtest_output[VALUE_COLUMN_NAME] = backtest_output[VALUE_COLUMN_NAME] * backtest_output["trend"]
+        linear_trend = utils.get_linear_predictions(
             backtest_output.reset_index()["trend"],
             [i for i in range(0, len(backtest_output["trend"]))]
         )
-        backtest_output[VALUE_COLUMN_NAME] = backtest_output[VALUE_COLUMN_NAME] * backtest_output["trend"]
+        backtest_output["linear_trend"] = linear_trend.values
         backtest_output["seasonal_predicted"] = predicted
-        backtest_output["predicted"] = backtest_output["trend"] * backtest_output["seasonal_predicted"]
+        backtest_output["predicted"] = backtest_output["linear_trend"] * backtest_output["seasonal_predicted"]
 
         # Run full seasonal forecast
         dataframe_forecast = self.create_time_series_features(backfill_dataframe, frequency, backtest=False)
@@ -618,14 +624,20 @@ class RandomForest(BaseModel):
             train = pd.concat([train, pd.DataFrame(row).T])
 
         # Add in trend and combine
-        backtest_output = pd.merge(left=test, right=decomposed_dataframe, how="left", right_index=True, left_index=True)
-        backtest_output["trend"] = utils.get_linear_predictions(
+        backtest_output = pd.merge(
+            left=test,
+            right=decomposed_dataframe,
+            how="left",
+            right_index=True,
+            left_index=True)
+        backtest_output[VALUE_COLUMN_NAME] = backtest_output[VALUE_COLUMN_NAME] * backtest_output["trend"]
+        linear_trend = utils.get_linear_predictions(
             backtest_output.reset_index()["trend"],
             [i for i in range(0, len(backtest_output["trend"]))]
         )
-        backtest_output[VALUE_COLUMN_NAME] = backtest_output[VALUE_COLUMN_NAME] * backtest_output["trend"]
+        backtest_output["linear_trend"] = linear_trend.values
         backtest_output["seasonal_predicted"] = predicted
-        backtest_output["predicted"] = backtest_output["trend"] * backtest_output["seasonal_predicted"]
+        backtest_output["predicted"] = backtest_output["linear_trend"] * backtest_output["seasonal_predicted"]
 
         # Run full seasonal forecast
         dataframe_forecast = self.create_time_series_features(backfill_dataframe, frequency, backtest=False)
@@ -668,15 +680,10 @@ class SARIMA(BaseModel):
         # Prepare dataframe for backtest
         backfill_dataframe = utils.create_backfill_time_series(original_dataframe, frequency)
         backfill_dataframe = pd.concat([original_dataframe, backfill_dataframe]).sort_values(by="period")
-        backfill_dataframe = backfill_dataframe.set_index("period").asfreq(frequency)
+        dataframe_backtest = backfill_dataframe.set_index("period").asfreq(frequency)
 
-        # Prepare dataframe
-        # Decompose time series
-        decomposed_dataframe = utils.get_seasonal_decomposition(backfill_dataframe["y"])
-        decomposed_dataframe = decomposed_dataframe.asfreq(frequency)
-
-        # Create Time Series Features for stationary
-        dataframe_backtest = pd.DataFrame(decomposed_dataframe.rename(columns={"seasonal": "y"})["y"])
+        # Parse original dataframe for usage later
+        dataframe = original_dataframe.set_index("period").asfreq(frequency)
 
         # Split into train and test
         # Check if enough data is provided to train on a full year
@@ -685,10 +692,8 @@ class SARIMA(BaseModel):
             if (dataframe_backtest.index.max() - train_start).days > 540:
                 train_end = train_start + relativedelta(years=1)
         train_mask = dataframe_backtest.index <= train_end
-        train_df = dataframe_backtest[train_mask]
-        train = train_df.reset_index(drop=True)
-        test_df = dataframe_backtest[~train_mask]
-        test = test_df.reset_index(drop=True)
+        train = dataframe_backtest[train_mask]
+        test = dataframe_backtest[~train_mask]
 
         # Create step-forward validation
         predicted = pd.DataFrame()
@@ -736,43 +741,17 @@ class SARIMA(BaseModel):
                         ).values
                 )
                 predicted = pd.concat([predicted, predictions])
-
-        # Add in trend and combine
-        backtest_output = pd.merge(
-            left=test_df,
-            right=decomposed_dataframe,
-            how="left",
-            right_index=True,
-            left_index=True)
-        backtest_output[VALUE_COLUMN_NAME] = backtest_output[VALUE_COLUMN_NAME] * backtest_output["trend"]
-        linear_trend = utils.get_linear_predictions(
-            backtest_output.reset_index()["trend"],
-            [i for i in range(0, len(backtest_output["trend"]))]
-        )
-        backtest_output["linear_trend"] = linear_trend.values
-        backtest_output["seasonal_predicted"] = predicted.values
-        backtest_output["predicted"] = backtest_output["linear_trend"] * backtest_output["seasonal_predicted"]
+        predicted[0] = predicted[0].apply(lambda x: x if x > 0 else 1)
 
         # Create future forecast
-        # Make trend predictions
-        trend_history = decomposed_dataframe[~decomposed_dataframe["trend"].isnull()]
-        trend_history = trend_history.reset_index(drop=True)["trend"]
-        linear_predictions = utils.get_linear_predictions(
-            trend_history,
-            [i for i in range(len(trend_history), len(trend_history) + len(forecast_period_list))])
-        # Make seasonal predictions
         model = SARIMAX(dataframe_backtest, order=self.order, seasonal_order=self.seasonal_order)
         results = model.fit(method='powell', disp=False)
-        seasonal_predictions = results.forecast(steps=len(forecast_period_list))
+        predictions = results.forecast(steps=len(forecast_period_list))
 
-        assembled_forecast = pd.DataFrame({
-            "period": forecast_period_list,
-            "linear": linear_predictions.values,
-            "seasonal": seasonal_predictions.values
-        })
-        assembled_forecast.set_index("period", inplace=True)
+        forecast = pd.Series(index=forecast_period_list, data=predictions)
+        forecast = forecast.apply(lambda x: x if x > 0 else 1)
 
-        return backtest_output[VALUE_COLUMN_NAME], backtest_output["predicted"], assembled_forecast["linear"] * assembled_forecast["seasonal"]
+        return test[VALUE_COLUMN_NAME], predicted[0].values, forecast
 
 
 def initialize_model(model_name: str):
