@@ -73,7 +73,8 @@ def create_backfill_time_series(original_df, frequency):
     first_full_year_mask = curve_df["period"] <= first_year_end
 
     total_growth = curve_df[last_full_year_mask].y.sum() / curve_df[first_full_year_mask].y.sum()
-    annual_growth = total_growth / ((days_provided - 365) / 365)
+    total_years = (days_provided - 365) / 365
+    annual_growth = np.exp(np.log(total_growth) / total_years)
 
     # Fill in dates
     curve_df["week"] = curve_df["period"].dt.isocalendar().week
